/* calendar for bootstrap css by     *
 *       David Christiansen          *
 *       http://www.techdarkside.com/creating-a-calendar-with-twitter-bootstrap-without-tables */

.calendar_grid {
  border: 1px solid gray;
  margin-bottom: 30px;
  align: center;
  background-image:url('file:///home/teejay/development/startup_ideas/flyhalf/root/static/images/gray_jean.png');
}

.month_header {
    background-color: gray;
    .span1 {
      padding-top: 5px;
      font-weight: bold;
      text-align: center;
    }
}

.notmonth {
    background-color: rgba(248,248,224,0.35);
    border: 1px solid whitesmoke;
}

.notmonth, .notmonth a { color: grey; }

.month.today { 
    background-color: rgba(250,250,246,0.7);
    border: 2px solid #D7F2FF;
}

.month {
    background-color: rgba(250,250,246,0.5);
    border: 1px solid whitesmoke;
}

.calendar_header {
    color: #FFFFFF;
    display: block;
    float: left;
    font-size: 15px;
    font-weight: 200;
    line-height: 1;
    background-color: #333333;
    text-align: center;
}

.calendar_header .span1 {
    padding: 8px 2px 8px 2px;
    margin:4px;
}

.calendar_container {
    width: 85%;
    margin-left: auto;
    margin-right: auto;
}

.row-fluid > [class*="span"] {
    float: left;
    margin-left: 2px;
}

.week .span1 {
    padding: 1px 2px 1px 2px;
    margin: 4px 2px 4px 2px;
    height: 80px;
    align: center;
}

ul.event_summary {
      margin: 4;
      list-style: none;
}


li.event_summary {
        list-style: none;
        padding: 2px;
           -moz-border-radius:4px;
        -webkit-border-radius:4px;
                border-radius:4px;
   }
}





